<?php
/**
 * function wpminv_add_default_admin_settings()
 *
 * adds the default plugin add settings to the settings array
 */
function wpminv_add_default_admin_settings( $settings ) {
		
	/* add the company name setting */
	$settings[ 'company_name' ] = array(
		'label'				=> __( 'Company Name', 'simvoicing' ),
		'name'				=> 'company_name',
		'type'				=> 'text',
		'description'		=> __( 'Enter your company name (who the invoices are from).', 'simvoicing' )
	);
	
	/* add the company address setting */
	$settings[ 'company_address' ] = array(
		'label'				=> __( 'Company Address', 'simvoicing' ),
		'name'				=> 'company_address',
		'type'				=> 'wysiwyg',
		'description'		=> __( 'Enter your company address.', 'simvoicing' ),
		'textarea_rows'		=> '5',
	);
	
	/* add the contact email setting */
	$settings[ 'contact_email' ] = array(
		'label'				=> __( 'Contact Email', 'simvoicing' ),
		'name'				=> 'contact_email',
		'type'				=> 'email',
		'description'		=> __( 'Enter you contact email address to show in your invoices.', 'simvoicing' ),
		'sanitize_callback'	=> 'is_email'
	);
	
	/* add the contact tel setting */
	$settings[ 'contact_tel' ] = array(
		'label'				=> __( 'Contact Tel.', 'simvoicing' ),
		'name'				=> 'contact_tel',
		'type'				=> 'text',
		'description'		=> __( 'Enter you contact telephone number to show in your invoices.', 'simvoicing' )
	);
	
	/* add the bank account no. setting */
	$settings[ 'payment_details_intro' ] = array(
		'label'				=> __( 'Payment Details Intro Text.', 'simvoicing' ),
		'name'				=> 'payment_details_intro',
		'type'				=> 'wysiwyg',
		'description'		=> __( 'Add some text to introduce your payment methods here.', 'simvoicing' ),
		'sanitize_callback'	=> 'wp_kses_post'
	);
	
	/* add the bank account no. setting */
	$settings[ 'bank_account_number' ] = array(
		'label'				=> __( 'Bank Account No.', 'simvoicing' ),
		'name'				=> 'bank_account_number',
		'type'				=> 'number',
		'description'		=> __( 'Enter you bank account number for payments.', 'simvoicing' ),
		'sanitize_callback'	=> 'intval'
	);
	
	/* add the bank sort code setting */
	$settings[ 'bank_sort_code' ] = array(
		'label'				=> __( 'Bank Sort Code', 'simvoicing' ),
		'name'				=> 'bank_sort_code',
		'type'				=> 'text',
		'description'		=> __( 'Enter you bank account sorting code for payments.', 'simvoicing' )
	);
	
	/* add the bank sort code setting */
	$settings[ 'invoice_prefix' ] = array(
		'label'				=> __( 'Invoice Prefix', 'simvoicing' ),
		'name'				=> 'invoice_prefix',
		'type'				=> 'text',
		'description'		=> __( 'Enter a prefix for all invoices. Leave blank for no prefix. All invoices references take the form of {prefix}{year}-{post_id}. This ensures they are unique.', 'simvoicing' ),
	);
	
	/* add the bank sort code setting */
	$settings[ 'payment_days' ] = array(
		'label'				=> __( 'Payment Days / Terms', 'simvoicing' ),
		'name'				=> 'payment_days',
		'type'				=> 'number',
		'description'		=> __( 'Enter the number of days you allow for payments. Leave blank for default which is 7 days.', 'simvoicing' ),
	);
	
	return $settings;
	
}

add_filter( 'wpminv_admin_settings', 'wpminv_add_default_admin_settings', 10 );

/**
 * function wpminv_register_settings()
 */
function wpminv_register_settings() {
	
	/* build array of setttings to register */
	$registered_settings = wpminv_get_admin_settings();
	
	/* check we have some settings to register */
	if( empty( $registered_settings ) ) {
		return;
	}
	
	/* loop through registered settings array */
	foreach( $registered_settings as $registered_setting ) {
		
		/* if the setting has a sanitize callback */
		if( ! empty( $registered_setting[ 'sanitize_callback' ] ) ) {
			$sanitize_callback = $registered_setting[ 'sanitize_callback' ];
		} else {
			$sanitize_callback = null;
		}
		
		/* build the setting name */
		$registered_setting_name = apply_filters( 'wpminv_admin_setting_prefix', 'wpminv_' ) . $registered_setting[ 'name' ];
	
		/* register a new setting with wp in the wpminv_settings group */
		register_setting( 'wpminv_admin_settings', $registered_setting_name, $sanitize_callback );
		
	}
	
}

add_action( 'admin_init', 'wpminv_register_settings', 20 );