<?php
/**
 * function wpminv_edit_client_column_titles()
 * filters the list of columns on the person post type
 * adding in some custom ones
 */
function wpminv_edit_client_column_titles( $columns ) {

	$columns = array(
		'cb'			=> '<input type="checkbox" />',
		'title'			=> __( 'Name', 'simvoicing' ),
		'email'			=> __( 'Email', 'simvoicing' ),
		'tel'		 	=> __( 'Tel', 'simvoicing' ),
		'address'		=> __( 'Address', 'simvoicing' )
	);

	return $columns;
}

add_filter( 'manage_edit-wpminv_client_columns', 'wpminv_edit_client_column_titles' );

/**
 * function wpminv_output_client_columns()
 * handles the output for our custom person columns
 */
function wpminv_output_client_columns( $column, $post_id ) {
	
	global $post;

	switch( $column ) {

		/* If displaying the 'duration' column. */
		case 'email' :

			/* get the email address */
			$email = get_post_meta( $post->ID, '_wpminv_email', true );

			/* if no email found. */
			if ( empty( $email ) ) {
				_e( 'Not Set', 'simvoicing' );
			}

			/* If there is a duration, append 'minutes' to the text string. */
			else {
				
				/* output the image */
				echo esc_html( $email );
				
			} // end if have email

			break;

		/* if displaying the tel column */
		case 'tel' :

			/* get the tel. */
			$tel = get_post_meta( $post_id, '_wpminv_tel', true );

			/* if tel was found. */
			if( $tel != '' ) {
				
				/* output the job title */
				echo esc_html( $tel );
				
			}

			/* If no terms were found, output a default message. */
			else {
				_e( 'Not set', 'simvoicing' );
			}

			break;
		
		/* if displaying the address column */
		case 'address' :
			
			/* get address parts */
			$address_one	= get_post_meta( $post->ID, '_wpminv_address_one', true );
			$address_two	= get_post_meta( $post->ID, '_wpminv_address_two', true );
			$towncity		= get_post_meta( $post->ID, '_wpminv_address_towncity', true );
			$postcode		= get_post_meta( $post->ID, '_wpminv_address_postcode', true );
			
			/* if we have an address part */
			if( $address_one != '' ) {
				echo esc_html( $address_one ) . '<br />';
			}
			
			/* if we have an address part */
			if( $address_two != '' ) {
				echo esc_html( $address_two ) . '<br />';
			}
			
			/* if we have an address part */
			if( $towncity != '' ) {
				echo esc_html( $towncity ) . '<br />';
			}
			
			/* if we have an address part */
			if( $postcode != '' ) {
				echo esc_html( $postcode ) . '<br />';
			}
			
			break;

		/* Just break out of the switch statement for everything else. */
		default :
			break;
	}
	
}

add_action( 'manage_wpminv_client_posts_custom_column', 'wpminv_output_client_columns', 10, 2 );