<?php
/**
 * function wpminv_invoice_meta_boxes()
 *
 * adds custom meta boxes to the post edit screens
 */
function wpminv_invoice_meta_boxes( $meta_boxes ) {
		
	/* set a prefix for all meta keys */
	$prefix = '_wpminv_';
	
	/* add the meta box for person info */
	$meta_boxes[] = array(
        'title' 	=> __( 'Invoice Details', 'simvoicing' ),
        'pages'		=> array(
        	'wpminv_invoice',
        ),
        'context'	=> 'side',
        'priority'	=> 'default',
        'fields'	=> array(
	        array( 
				'id'		=> $prefix . 'client', 
				'name'		=> __( 'Client', 'simvoicing' ),
				'desc'		=> __( 'Choose a client for this invoice.', 'wpmark-invoicing' ),
				'type'		=> 'post_select',
				'use_ajax'	=> true,
			    'query'		=> array(
			        'post_type'	=> 'wpminv_client'
			    ),
			    'cols'		=> 12
			),
			array( 
				'id'   		=> $prefix . 'due_date',
				'name'		=> __( 'Invoice due date', 'simvoicing' ),
				'type'		=> 'date',
				'desc'		=> __( 'Defaults to +7 days.', 'simvoicing' ),
				'cols'		=> 12
			),
			array( 
				'id'   		=> $prefix . 'invoice_status',
				'name'		=> __( 'Invoice Status', 'simvoicing' ),
				'type'		=> 'select',
				'desc'		=> __( 'Choose the status of the invoice.', 'simvoicing' ),
				'options'	=> apply_filters(
					'wpminv_invoice_status_options',
					array(
						'Unpaid'	=> __( 'Unpaid', 'simvoicing' ),
						'Paid'		=> __( 'Paid', 'simvoicing' )
					)
				),
				'cols'		=> 12
			),
			array( 
				'id'   		=> $prefix . 'currency',
				'name'		=> __( 'Currency', 'simvoicing' ),
				'type'		=> 'select',
				'desc'		=> __( 'Select the currency.', 'simvoicing' ),
				'options'	=> apply_filters(
					'wpminv_invoice_currency_options',
					array(
						'gbp'	=> __( 'GB Pounds Sterling', 'simvoicing' ),
						'eur'	=> __( 'EURO', 'simvoicing' ),
						'usd'	=> __( 'US Dollars', 'simvoicing' )
					)
				),
				'cols'		=> 12
			),
			array( 
				'id'   		=> $prefix . 'tax_percentage',
				'name'		=> __( 'Tax Percentage', 'simvoicing' ),
				'type'		=> 'number',
				'desc'		=> __( 'Enter the percentage tax rate for this invoice. Leave blank to not add tax.', 'simvoicing' ),
				'cols'		=> 12
			),
        )
    );
    
    /* add the meta box for person info */
	$meta_boxes[] = array(
        'title' 	=> __( 'Invoice Notes', 'simvoicing' ),
        'pages'		=> array(
        	'wpminv_invoice',
        ),
        'context'	=> 'normal',
        'priority'	=> 'default',
        'fields'	=> array(
	        array( 
				'id'   		=> $prefix . 'notes',
				'name'		=> '',
				'type'		=> 'wysiwyg',
				'options'	=> apply_filters(
					'wpminv_invoice_notes_options',
					array(
						'media_buttons'	=> false,
						'textarea_rows'	=> 8
					)
				),
				'desc'		=> __( 'Enter any notes for this invoice.', 'simvoicing' ),
				'cols'		=> 12
			),
	    )
	);
    
    /* add the meta box for invoice items */
	$meta_boxes[] = array(
        'title' 	=> __( 'Invoice Items', 'simvoicing' ),
        'pages'		=> array(
        	'wpminv_invoice',
        ),
        'context'	=> 'normal',
        'priority'	=> 'default',
        'fields'	=> array(
	        array( 
				'id'					=> $prefix . 'items', 
				'name'					=> '',
				'type'					=> 'group',
				'repeatable'			=> true,
				'sortable'				=> true,
				'string-repeat-field'	=> __( 'Add item', 'simvoicing' ),
				'string-delete-field'	=> __( 'Remove item', 'simvoicing' ),
				'fields'				=> array(
					array( 
						'id'   		=> 'quantity',
						'name'		=> __( 'Quantity', 'simvoicing' ),
						'type'		=> 'text',
						'desc'		=> __( 'Enter the no. of this item.', 'simvoicing' ),
						'cols'		=> 4
					),
					array( 
						'id'   		=> 'quantity_type',
						'name'		=> __( 'Quantity Type', 'simvoicing' ),
						'type'		=> 'text',
						'desc'		=> __( 'e.g. hour/day', 'simvoicing' ),
						'cols'		=> 4
					),
					array( 
						'id'   		=> 'price',
						'name'		=> __( 'Price', 'simvoicing' ),
						'type'		=> 'text',
						'desc'		=> __( 'Numbers only e.g. 20', 'simvoicing' ),
						'cols'		=> 4
					),
					array( 
						'id'   		=> 'description',
						'name'		=> __( 'Description', 'simvoicing' ),
						'type'		=> 'textarea',
						'desc'		=> __( 'Enter a description of this product/service.', 'simvoicing' ),
						'cols'		=> 12
					),
				)
			)
        )
    );
    
    return $meta_boxes;

}

add_filter( 'cmb_meta_boxes', 'wpminv_invoice_meta_boxes' );