<?php
/**
 * function wpminv_save_client_on_save()
 *
 * takes the entered first and last name and then saves
 * these as the posts title
 *
 * @param	(int) $post_id is the id of the current post being saved
 */
function wpminv_save_client_on_save( $post_id ) {
	
	/* if we have a client id posted */
	if( isset( $_POST[ '_wpminv_company_name' ][ 'cmb-field-0' ] ) ) {
		
		/* get a company name */
		$title = sanitize_text_field( $_POST[ '_wpminv_company_name' ][ 'cmb-field-0' ] );
		
		/* if the client has no company name */
		if( $title == '' ) {
			
			/* get the first and last name of this person */
			$first_name = sanitize_text_field( $_POST[ '_wpminv_first_name' ][ 'cmb-field-0' ] );
			$last_name = sanitize_text_field( $_POST[ '_wpminv_last_name' ][ 'cmb-field-0' ] );
			
			/* build post title of client first and last name */
			$title = $first_name . ' ' . $last_name;
			
		}
		
		/* unhook this function so it doesn't loop infinitely */
		remove_action( 'save_post_wpminv_client', 'wpminv_save_client_on_save' );
	
		/* update the post title to store the first and last name */
		wp_update_post(
			apply_filters(
				'wpminv_client_save_post_args',
				array(
					'ID'			=> $post_id,
					'post_title'	=> esc_html( $title ),
					'post_name'		=> sanitize_title( $title )
				),
				$post_id
			)
		);
	
		/* re-hook this function */
		add_action( 'save_post_wpminv_client', 'wpminv_save_client_on_save' );
	
	} // end if have company name set
	
}

add_action( 'save_post_wpminv_client', 'wpminv_save_client_on_save' );

/**
 * function wpminv_save_invoice_on_save()
 *
 * Saves the title of the invoice on post save
 *
 * @param	(int) $post_id is the id of the current post being saved
 */
function wpminv_save_invoice_on_save( $post_id ) {
	
	/* if we have a client id posted */
	if( isset( $_POST[ '_wpminv_client' ][ 'cmb-field-0' ] ) ) {
		
		/* get a company name */
		$client_post_id = sanitize_text_field( $_POST[ '_wpminv_client' ][ 'cmb-field-0' ] );
		
		/* if we have a client post id */
		if( $client_post_id != '' ) {
			
			/* get the clients company name */
			$title = get_post_meta( $client_post_id, '_wpminv_company_name', true );
			
			/* if client has no company name */
			if( $title == '' ) {
				
				/* set title to company name */
				$title = get_post_meta( $client_post_id, '_wpminv_first_name', true ) . ' ' . get_post_meta( $client_post_id, '_wpminv_last_name', true );
				
			}
		
		/* no client added to invoice */
		} else {
			
			$title = 'No client selected';
			
		}
		
		/* unhook this function so it doesn't loop infinitely */
		remove_action( 'save_post_wpminv_invoice', 'wpminv_save_invoice_on_save', 99, 1 );
		
		/* update the post title to store the first and last name */
		wp_update_post(
			apply_filters(
				'wpminv_invoice_save_post_args',
				array(
					'ID'			=> $post_id,
					'post_title'	=> esc_html( $title ),
					'post_name'		=> sanitize_title( $post_id )
				),
				$post_id
			)
		);
		
		/* re-hook this function */
		add_action( 'save_post_wpminv_invoice', 'wpminv_save_invoice_on_save', 99, 1 );
		
	} // end if client id posted
	
}

add_action( 'save_post_wpminv_invoice', 'wpminv_save_invoice_on_save', 99, 1 );