<?php
/**
 * wpminv_jobs_archive - outputs invoices archive list in a shortcode
 * 
 * @param  array $atts is the array of shortcode attributes
 * @param  string $content is the content to output between the shortcode
 * 
 * @return shortcode output html
 */
function wpminv_jobs_archive_shortcode( $atts, $content = '', $shortcode_tag ) {

	/* enqueue front-end styles */
	wp_enqueue_style( 'wpminv_styles', plugins_url( '/assets/css/simvoicing-style.css', dirname(__FILE__) ) );

	/* set some attrubute defaults if not passed in by the shortcode */
	$atts = shortcode_atts(
		array(
			'title' => '',
		),
		$atts,
		'simvoicing_archive'
	);

	/* lets query all the invoices in the system */
	$invoices = new WP_Query(
		array(
			'posts_per_page'	=> -1,
			'post_type'			=> 'wpminv_invoice'
		)
	);

	/* turn on output buffering */
	ob_start();

	/* check if we have invoices to show */
	if( $invoices->have_posts() ) {

		?>
		<div class="<?php echo apply_filters( 'wpminv_invoice_archive_wrapper_class', 'invoice-archive' ); ?>">
		<?php

		// Declare some helper vars
		$previous_year = $year = 0;
		$previous_month = $month = 0;
		$ul_open = false;
		$month_count = 0;

		/* loop through each invoice */
		while( $invoices->have_posts() ) : $invoices->the_post();

			/* get the year, month and day of this invoice */
			$year = get_the_time( 'Y' );
			$month = get_the_time( 'm' );
			$day = get_the_time( 'd' );

			/* if this invoices year or month is not the same as the previous posts year or month */
			if( $year != $previous_year || $month != $previous_month ) {

				/* increment month count */
				$month_count++;

				/* if we have an open list tag - then close it */
				if( $ul_open == true ) {
					?>
					</ul></div>
					<?php

				}

				/* output this months title */
				?>
				<div class="month-wrapper month-wrapper-<?php echo esc_attr( $month_count ); ?> month-wrapper-<?php echo esc_attr( strtolower( get_the_time( 'F-Y' ) ) ); ?>">
				<h3><?php the_time( 'F Y' ); ?></h3>
				<?php

				/* open the list items again */
				?>
				<ul class="month-invoice-list">
				<?php

				/* reset the list as open */
				$ul_open = true;

			} // end if this invoices year or month are equal to the last

			/* reset the previous year and month vars to this posts year and month */
			$previous_year	= $year;
			$previous_month	= $month;

			/* output the list item for this invoice - title, linking to permalink page of invoice */
			?>

			<li <?php post_class( wpminv_get_invoice_status_class() ); ?> id="invoice-<?php the_ID(); ?>">
				<a href="<?php the_permalink(); ?>"><?php the_title(); ?> - <?php the_time( 'd/m/Y' ); ?></a>
			</li>

			<?php

		/* end invoices loop */
		endwhile;

		/* close the open unordered list */
		?>
		</ul></div>
		<?php

	} // end if have invoices

	/* reset the query */
	wp_reset_query();

	/* return the buffere content */
	return ob_get_clean();

}

add_shortcode( 'simvoicing_archive', 'wpminv_jobs_archive_shortcode', 10, 3 );