<?php
/**
 * function wpminv_get_template_part()
 *
 * @param mixed $slug
 * @param string $name (default: '')
 */
function wpminv_get_template_part( $slug, $name = '' ) {
	
	$template = '';

	// Look in yourtheme/slug-name.php and yourtheme/wpminv/slug-name.php
	if ( $name ) {
		$template = locate_template( array( "{$slug}-{$name}.php", '/simvoiving/' . "{$slug}-{$name}.php" ) );
	}

	// Get default slug-name.php
	if ( ! $template && $name && file_exists( SIMVOICING_LOCATION . "/templates/{$slug}-{$name}.php" ) ) {
		$template = SIMVOICING_LOCATION . "/templates/{$slug}-{$name}.php";
	}

	// If template file doesn't exist, look in yourtheme/slug.php and yourtheme/wpbb/templates/slug.php
	if ( ! $template ) {
		$template = locate_template( array( "{$slug}.php", '/simvoiving/' . "{$slug}.php" ) );
	}

	// Allow 3rd party plugin filter template file from their plugin
	if ( ( ! $template ) || $template ) {
		$template = apply_filters( 'wpminv_get_template_part', $template, $slug, $name );
	}

	if ( $template ) {
		load_template( $template, false );
	}
	
}

/**
 * function wpminv_get_invoice_client_id()
 *
 * gets the associated client post id for an invoice
 *
 * @param	int		$invoice_id is the invoice post id to get the client of
 * @return	mixed	retrns is associated client post id (int) for this invoice
 *					or returns false is not associated client found
 */
function wpminv_get_invoice_client_id( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	/* get the client id for this invoice */
	$client_id = get_post_meta( $invoice_id, '_wpminv_client', true );
	
	/* if no client id is set */
	if( $client_id == '' ) {
		
		/* set client id to false */
		$client_id = false;
		
	}
	
	/* return the filtered client id */
	return apply_filters( 'wpimnv_get_invoice_client_id', absint( $client_id ), $invoice_id );
	
}

/**
 * function wpminv_get_invoiceto_name()
 *
 * returns the clients company name if present or there first and last
 * name if no company name provided.
 *
 * @param	int		$client_id is the client post id of this invoice
 */
function wpminv_get_invoiceto_name( $client_id = 0 ) {
	
	/* if no client post id provided */
	if( $client_id == 0 ) {
		return new WP_Error(
			'client_not_exist',
			__( 'No client exists with this client ID.', 'simvoicing' )
		);
	}
	
	/* get the clients company name */
	$company_name = get_post_meta( $client_id, '_wpminv_company_name', true );
	
	/* if we have a company name */
	if( $company_name != '' ) {
		
		/* set invoice to name to company name */
		$invoiceto = $company_name;
	
	/* no company name added */
	} else {
		
		/* get the first and last names of the client */
		$first_name = get_post_meta( $client_id, '_wpmin_first_name', true );
		$last_name	= get_post_meta( $client_id, '_wpmin_last_name', true );
		
		/* buiid first last name string */
		$invoiceto = $first_name . ' ' . $last_name;
		
	}
	
	/* build output */
	return apply_filters( 'wpminv_get_client_name', esc_html( $invoiceto ), $client_id );
	
}

/**
 * function wpminv_get_invoiceto_address()
 *
 * returns the invoice to address string
 *
 * @param	int		$client_id is the client post id of this invoice
 * @param	string	$sep is the seperator for the address parts
 *
 */
function wpminv_get_invoiceto_address( $client_id = 0, $sep = ', ' ) {
	
	/* if no client post id provided */
	if( $client_id == 0 ) {
		return new WP_Error(
			'client_not_exist',
			__( 'No client exists with this client ID.', 'simvoicing' )
		);
	}
	
	/* get all the address parts */
	$address_one		= get_post_meta( $client_id, '_wpminv_address_one', true );
	$address_two		= get_post_meta( $client_id, '_wpminv_address_two', true );
	$address_towncity	= get_post_meta( $client_id, '_wpminv_address_towncity', true );
	$address_postcode	= get_post_meta( $client_id, '_wpminv_address_postcode', true );
	
	/* build the address string */
	$address = '';

	/* if we have the address part */
	if( $address_one != '' ) {
		$address .= esc_html( $address_one ) . $sep;
	}

	/* if we have the address part */
	if( $address_two != '' ) {
		$address .= esc_html( $address_two ) . $sep;
	}
	 
	
	return apply_filters( 'wpminv_get_invoiceto_address', $address, $client_id );
	
}

/**
 * function wpminv_get_invoiceto_name()
 *
 * returns the invoice to name string
 *
 * @param	int		$client_id is the client post id of this invoice
 *
 */
function wpminv_get_invoiceto_contact_name( $client_id = 0 ) {
	
	/* if no client post id provided */
	if( $client_id == 0 ) {
		return new WP_Error(
			'client_not_exist',
			__( 'No client exists with this client ID.', 'simvoicing' )
		);
	}
	
	/* get the first and last names of the client */
	$first_name = get_post_meta( $client_id, '_wpminv_first_name', true );
	$last_name	= get_post_meta( $client_id, '_wpminv_last_name', true );
	
	/* buiid first last name string */
	$invoiceto_name = esc_html( $first_name ) . ' ' . esc_html( $last_name );
	
	return apply_filters( 'wpminv_get_invoiceto_contact_name', esc_html( $invoiceto_name ), $client_id );
	
}

/**
 * function wpminv_get_invoiceto_email()
 *
 * returns the invoice to email string
 *
 * @param	int		$client_id is the client post id of this invoice
 *
 */
function wpminv_get_invoiceto_contact_email( $client_id = 0 ) {
	
	/* if no client post id provided */
	if( $client_id == 0 ) {
		return new WP_Error(
			'client_not_exist',
			__( 'No client exists with this client ID.', 'simvoicing' )
		);
	}
	
	/* get the first and last names of the client */
	$email = get_post_meta( $client_id, '_wpminv_email', true );
	
	return apply_filters( 'wpminv_get_invoiceto_contact_email', esc_html( $email ), $client_id );
	
}

/**
 * function wpminv_get_admin_settings
 *
 * returns an array of adming settings added through the filter
 */
function wpminv_get_admin_settings() {
	
	return apply_filters(
		'wpminv_admin_settings',
		array()
	);
	
}

/**
 * function wpminv_get_setting()
 *
 * returns an admin setting from the plugin or the default
 * if the settings returns nothing
 */
function wpminv_get_setting( $name, $default = '' ) {
	
	/* get the option from the database */
	$setting = get_option( 'wpminv_' . $name );
	
	/* check we have something returned */
	if( $setting == '' ) {
		
		/* set to default */
		$setting = $default;
	}
	
	return apply_filters( 'wpminv_get_setting', $setting, $name, $default );
	
}

/**
 * function wpminv_is_wpbb_taxonomy()
 */
function wpminv_is_wpbb_taxonomy() {
	return is_tax( get_object_taxonomies( 'wpminv_invoice' ) );
}

/**
 * function wpminv_is_invoice_template_view()
 *
 * checks to see if the current template view on the front end is an invoice view
 * i.e. it involves the invoices post type in some way.
 * returns true if it is and false if not.
 */
function wpminv_is_invoice_template_view() {

	/* set invoice view to false to start with */
	$invoice_view = false;
	
	/* if this is a single post page for invoices */
	if( is_singular( 'wpminv_invoice' ) ) {
		
		/* invoice view to true */
		$invoice_view = true;
		
	}
	
	/* if this is a tax archive which belongs to invoices */
	if( wpminv_is_wpbb_taxonomy() ) {
		
		/* invoice view to true */
		$invoice_view = true;
		
	}
	
	/* is this the invoices post type archive */
	if( is_post_type_archive( 'wpminv_invoice' ) ) {
		
		/* invoice view to true */
		$invoice_view = true;
		
	}
	
	return apply_filters( 'wpminv_is_invoice_template_view', $invoice_view );
	
}

/**
 * function wpminv_body_class()
 *
 * adds a body class to those pages which handle invoices
 */
function wpminv_body_class( $classes ) {
	
	/* if this is an invoice template view */
	if( wpminv_is_invoice_template_view() ) {
		
		/* add to the body class */
		$classes[] = 'invoice-template';
		
	}
	
	return $classes;
	
}

add_filter( 'body_class', 'wpminv_body_class' );

/**
 * function wpminv_get_currency()
 *
 * gets the currency of the invoice with id passed and returns the appropriate
 * currency symbol as html entity code
 */
function wpminv_get_currency( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	/* get the selected currency */
	$currency = get_post_meta( $invoice_id, '_wpminv_currency', true );
	
	/* convert the currency to a symbol */
	switch( $currency ) {
	
		/* if currency is euros */
		case 'eur' :
			var_dump( $currency );
			$symbol = '&euro;';
			break;
		
		/* if currency is us dollars */
		case 'usd' :
		
			$symbol = '&#36;';
			break;
		
		/* default */
		default :
		
			$symbol = '&pound;';
			break;
		
	} // end switch currency
	
	return apply_filters( 'wpminv_get_currency', esc_html( $symbol ), $invoice_id );
	
}

/**
 * function wpminv_get_invoice_reference()
 *
 * returns the invoice reference for the given invoice id of the current
 * invoice in the loop
 */
function wpminv_get_invoice_reference( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	/* get the invoice preifx */
	$prefix = wpminv_get_setting( 'invoice_prefix', '' );
	
	return apply_filters( 'wpminv_get_invoice_reference', esc_html( $prefix . get_the_date( 'Y' ) . '-' . $invoice_id ), $invoice_id );
	
}

/**
 * function wpminv_get_payment_due_date()
 *
 * returns the date when an invoice is due for payment for the give
 * invoice id or the current invoice in the loop
 */
function wpminv_get_payment_due_date( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	/* do we have a due date entered */
	$invoice_payment_due = get_post_meta( $invoice_id, '_wpminv_due_date', true );

	/* no set due date */
	if( $invoice_payment_due == '' ) {
		
		/* get the payment terms from the settings */
		$payment_days = wpminv_get_setting( 'payment_days', '7' );
	
		/* get the published date of the invoice */
		$invoice_date = get_the_date( 'd-m-Y', $invoice_id );
		
		/* add payments terms to invoice date */
		$invoice_payment_due = date( 'd-m-Y', strtotime( $invoice_date . '+' . $payment_days . ' days' ) );
		
	} else {
		
		$invoice_payment_due = date( 'd-m-Y', strtotime( $invoice_payment_due ) );
		
	}
			
	return apply_filters( 'wpminv_get_payment_due_date', esc_html( $invoice_payment_due ), $invoice_id );
	
}

/**
 * function wpminv_get_invoice_items()
 *
 * @param int	$invoice_id the invoice id to get items of
 */
function wpminv_get_invoice_items( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	$items = get_post_meta( $invoice_id, '_wpminv_items', false );
	
	/* if we have no status */
	if( $items == '' ) {
		
		/* set status to unpaid */
		$items = false;
		
	}
	
	return apply_filters( 'wpminv_get_invoice_items', $items, $invoice_id );
	
}

/**
 * function wpminv_get_invoice_status()
 *
 * @param int	$invoice_id the invoice id to get the status of 
 */
function wpminv_get_invoice_status( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	$status = get_post_meta( $invoice_id, '_wpminv_invoice_status', true );
	
	/* if we have no status */
	if( $status == '' ) {
		
		/* set status to unpaid */
		$status = 'Unpaid';
		
	}
	
	return apply_filters( 'wpminv_get_invoice_status', esc_html( $status ), $invoice_id );
	
}

/**
 * function wpminv_get_invoice_tax_rate(
 *
 * @param int	$invoice_id the invoice id to get the status of
 */
function wpminv_get_invoice_tax_rate( $invoice_id = 0 ) {
	
	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}
	
	$tax_rate = get_post_meta( $invoice_id, '_wpminv_tax_percentage', true );
	
	/* if we have no status */
	if( $tax_rate == '' ) {
		
		/* set status to unpaid */
		$tax_rate = '0';
		
	}
	
	return apply_filters( 'wpminv_get_invoice_tax_rate', esc_html( $tax_rate ), $invoice_id );
	
}

/**
 * [wpminv_get_invoice_notes description]
 * @param  string $invoice_id the id of the invoice to return the notes for
 */
function wpminv_get_invoice_notes( $invoice_id = 0 ) {

	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}

	$notes = get_post_meta( $invoice_id, '_wpminv_notes', true );

	/* if we have invoice notes */
	if( $notes != '' ) {

		return apply_filters( 'wpminv_invoice_notes', $notes, $invoice_id );

	}

	return false;

}

/**
 * @param  int $invoice_id is the id of the invoice to return the class for
 * @return mixed string if the invoice status returns correctly or false if the invoice doesn't exist
 * 
 */
function wpminv_get_invoice_status_class( $invoice_id = 0 ) {

	global $post;
	
	/* if not invoice post id provided - use current */
	if( $invoice_id == 0 ) {
		$invoice_id = $post->ID;
	}

	/* store class string output here */
	$classes = array();

	/* get the status of the current invoice */
	$status = wpminv_get_invoice_status( $invoice_id );

	/* add the status class */
	$classes[] = strtolower( $status );

	/* get the payment due date of the current invoice */
	$payment_due = strtotime( wpminv_get_payment_due_date() );

	/* get todays date */
	$today = strtotime( date( 'd-m-Y' ) );

	/* is the invoice overdue */
	if( $payment_due < $today && $status == 'Unpaid' ) {

		/* add overdue class */
		$classes[] = 'overdue';

	}

	/* implode classes array into a string with spaces */
	$classes = implode( ' ', $classes );

	return apply_filters( 'wpminv_get_invoice_status_class', $classes, $invoice_id );

}