<?php
/*
Plugin Name: Simvoicing
Description: Simvoicing (short for Simple Invoicing) is a really simple way to create simple invoices in WordPress. It allows you to create clients, storing invoice to details and link them to invoices. Each invoice can have multiple rows of services/products and each invoice can have a set tax (or VAT) rate and a specific currency.
Author: Mark Wilkinson
Author URI: http://markwilkinson.me
Version: 1.0
Text Domain: simvoicing

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

*/

/* exist if directly accessed */
if( ! defined( 'ABSPATH' ) ) exit;

/* define variable for path to this plugin file. */
define( 'SIMVOICING_LOCATION', dirname( __FILE__ ) );
define( 'SIMVOICING_LOCATION_URL', plugins_url( '', __FILE__ ) );

/* check whether the metabox class already exists - and load it if not */
if( ! class_exists( 'CMB_Meta_Box' ) ) {
	require_once( dirname( __FILE__ ) . '/inc/custom-meta-boxes/custom-meta-boxes.php' );
}

/* load in the plugins post types */
require_once dirname( __FILE__ ) . '/admin/post-types/client.php';
require_once dirname( __FILE__ ) . '/admin/post-types/invoice.php';

/* load in the plugins meta boxes */
require_once dirname( __FILE__ ) . '/admin/meta-boxes/client.php';
require_once dirname( __FILE__ ) . '/admin/meta-boxes/invoice.php';
require_once dirname( __FILE__ ) . '/admin/meta-boxes/extra-fields.php';

/* load in the admin includes */
require_once dirname( __FILE__ ) . '/admin/admin.php';
require_once dirname( __FILE__ ) . '/admin/admin-menus.php';
require_once dirname( __FILE__ ) . '/admin/admin-settings.php';
require_once dirname( __FILE__ ) . '/admin/save-post.php';

/* load other includes */
require_once dirname( __FILE__ ) . '/inc/simvoicing-functions.php';
require_once dirname( __FILE__ ) . '/inc/template-functions.php';
require_once dirname( __FILE__ ) . '/inc/template-hooks.php';
require_once dirname( __FILE__ ) . '/inc/shortcodes.php';

/**
 * loads the plugin text domain etc.
 */
function wpminv_load_plugin_text_domain() {
	load_plugin_textdomain( 'simvoicing', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
add_action( 'plugins_loaded', 'wpminv_load_plugin_text_domain' );

/**
 * function wpminv_template_loader()
 *
 * checks whether the template exists in the theme
 * if it does then it loads the template from the theme
 * otherwise it loads it in from the plugin
 */
function wpminv_template_loader( $template ) {
		
	$find = array();
	$file = '';
		
	/* is this a single job post view */
	if( is_singular( 'wpminv_invoice' ) ) {
		
		$file = 'single-wpminv_invoice.php';
		$find[] = $file;
		$find[] = 'simvoiving/' . $file;

	}
		
	/* if we have a file to include */
	if( $file != '' ) {
		
		/* find the template in the theme */
		$template = locate_template( array_unique( $find ) );
		
		/* if we have no template in the theme */
		if ( ! $template ) {
			
			/* set the template to the file included in the plugin */
			$template = SIMVOICING_LOCATION . '/templates/' . $file;
			
		}
		
	}
	
	return $template;
	
}

add_filter( 'template_include', 'wpminv_template_loader', 10 );

/**
 * function wpminv_add_front_end_styles()
 *
 * enqueues the front end stylesheet for the plugin.
 */
function wpminv_add_front_end_styles() {
	
	/* is this a template view which uses our invoices post type */
	if( wpminv_is_invoice_template_view() ) {
		
		/* enqueue front-end styles */
		wp_enqueue_style( 'wpminv_styles', plugins_url( '/assets/css/simvoicing-style.css', __FILE__ ) );
		
	}
				
}

add_action( 'wp_enqueue_scripts', 'wpminv_add_front_end_styles' );